vpnengine/pkiservice/src/pkimapper.cpp
branchRCL_3
changeset 38 9f4e37332ce5
parent 2 ef893827b4d1
child 40 473321461bba
--- a/vpnengine/pkiservice/src/pkimapper.cpp	Mon Jun 21 16:49:56 2010 +0300
+++ b/vpnengine/pkiservice/src/pkimapper.cpp	Thu Aug 19 10:54:34 2010 +0300
@@ -445,11 +445,9 @@
         if(mapping->IsMatchingL(aDescriptor, aInfoOnly, aStoreType))
             {
             // If we found a match, process it further
-            _LIT(KMidp2Label, "MIDP2");
-            TBuf<12> buf;
-            buf.Append(KMidp2Label);
-            // Discard all MIDP2 certificates to avoid label-mapping problem
-            if (buf.Compare(mapping->Label()) != 0)
+            _LIT(KJavaTrustRootLabel, "Java Trust Root");
+            // Discard all "Java Trust Root" certificates to avoid label-mapping problem
+            if (mapping->Label().Compare(KJavaTrustRootLabel) != 0)
                 {
                 if(mapping->EndTime() > furthestEndTime)
                     {
@@ -461,7 +459,7 @@
                 }
             else 
                 {
-                LOG(Log::Printf(_L("Found a cert, but it was a MIDP2 one - continuing search")));
+                LOG(Log::Printf(_L("Found a cert, but it was a \"Java Trust Root\" one - continuing search")));
                 }
             }
         }